OC.L10N.register(
    "core",
    {
    "Please select a file." : "Seleccione un ficheiro.",
    "File is too big" : "O ficheiro é grande de máis",
    "The selected file is not an image." : "O ficheiro seleccionado non é unha imaxe.",
    "The selected file cannot be read." : "O ficheiro seleccionado non pode ser lido.",
    "The file was uploaded" : "O ficheiro foi enviado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "O ficheiro enviado excede a directiva indicada por upload_max_filesize de php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "O ficheiro enviado excede da directiva MAX_FILE_SIZE especificada no formulario HTML",
    "The file was only partially uploaded" : "O ficheiro só foi parcialmente enviado",
    "No file was uploaded" : "Non se enviou ningún ficheiro",
    "Missing a temporary folder" : "Falta un cartafol temporal",
    "Could not write file to disk" : "Non foi posíbel escribir o ficheiro no disco",
    "A PHP extension stopped the file upload" : "Unha extensión PHP detivo o envío de ficheiros",
    "Invalid file provided" : "O ficheiro fornecido non é válido",
    "No image or file provided" : "Non forneceu ningunha imaxe ou ficheiro",
    "Unknown filetype" : "Tipo de ficheiro descoñecido",
    "An error occurred. Please contact your admin." : "Produciuse un erro. Póñase en contacto coa administración da instancia.",
    "Invalid image" : "Imaxe incorrecta",
    "No temporary profile picture available, try again" : "Non hai unha imaxe temporal de perfil dispoñíbel, volva tentalo",
    "No crop data provided" : "Non indicou como recortar",
    "No valid crop data provided" : "Os datos recortados fornecidos non son válidos",
    "Crop is not square" : "O recorte non é cadrado",
    "State token does not match" : "O testemuño de estado non coincide",
    "Invalid app password" : "Contrasinal da aplicación incorrecto ",
    "Could not complete login" : "Non foi posíbel completar o acceso",
    "State token missing" : "Falta o testemuño de estado",
    "Your login token is invalid or has expired" : "O seu testemuño de acceso non é válido ou caducou",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Esta edición comunitaria de Nextcloud non é compatíbel e as notificacións emerxentes son limitadas.",
    "Login" : "Acceder",
    "Unsupported email length (>255)" : "Lonxitude de correo-e non admitida (>255)",
    "Password reset is disabled" : "O restabelecemento de contrasinal está desactivado",
    "Could not reset password because the token is expired" : "Non foi posíbel restabelecer o contrasinal porque o testemuños caducou",
    "Could not reset password because the token is invalid" : "Non foi posíbel restabelecer o contrasinal porque o testemuño non é válido",
    "Password is too long. Maximum allowed length is 469 characters." : "O contrasinal é longo de máis. A lonxitude máxima permitida é de 469 caracteres.",
    "%s password reset" : "Restabelecer o contrasinal %s",
    "Password reset" : "Restabelecer o contrasinal",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Prema no seguinte botón para restabelecer o seu contrasinal. Se Vde. non solicitou o restabelecemento do contrasinal, entón ignore este correo.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Prema na seguinte ligazón para restabelecer o seu contrasinal. Se Vde. non solicitou o restabelecemento do contrasinal, entón ignore este correo.",
    "Reset your password" : "Restabelecer o seu contrasinal",
    "The given provider is not available" : "O provedor indicado non está dispoñíbel",
    "Task not found" : "Non se atopou a tarefa",
    "Internal error" : "Produciuse un erro interno",
    "Not found" : "Non atopado",
    "Bad request" : "Solicitude incorrecta",
    "Requested task type does not exist" : "O tipo de tarefa solicitado non existe",
    "Necessary language model provider is not available" : "O provedor de modelos de linguaxe necesario non está dispoñíbel",
    "No text to image provider is available" : "Non hai ningún provedor de texto a imaxe dispoñíbel",
    "Image not found" : "Non se atopou a imaxe",
    "No translation provider available" : "Non hai ningún provedor de tradución dispoñíbel",
    "Could not detect language" : "Non foi posíbel detectar o idioma",
    "Unable to translate" : "Non é posíbel traducir",
    "Nextcloud Server" : "Servidor de Nextcloud",
    "Some of your link shares have been removed" : "Retiráronse algunhas das súas ligazóns para compartir",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Por mor dun fallo de seguranza tivemos que retirar algunhas das súas ligazóns para compartir. Vexa a ligazón para obter máis información.",
    "The account limit of this instance is reached." : "Acadouse o límite de contas desta instancia.",
    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Introduza a súa chave de subscrición na aplicación de asistencia para aumentar o límite da conta. Isto tamén lle outorga todos os beneficios adicionais que ofrece Nextcloud Enterprise e é moi recomendábel para a operativa nas empresas.",
    "Learn more ↗" : "Máis información ↗",
    "Preparing update" : "Preparando a actualización",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Paso do arranxo:",
    "Repair info:" : "Información do arranxo:",
    "Repair warning:" : "Advertencia de arranxo:",
    "Repair error:" : "Erro do arranxo:",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Use o actualizador da liña de ordes porque a actualización a través do navegador está desactivada no seu config.php.",
    "Turned on maintenance mode" : "Modo de mantemento activado",
    "Turned off maintenance mode" : "Modo de mantemento desactivado",
    "Maintenance mode is kept active" : "Mantense activo o modo de mantemento",
    "Updating database schema" : "Actualizando o esquema da base de datos",
    "Updated database" : "Base de datos actualizada",
    "Update app \"%s\" from App Store" : "Actualizar a aplicación «%s» desde a tenda de aplicacións",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Comprobar se é posíbel actualizar o esquema da base de datos para %s (isto pode levarlle bastante, dependendo do tamaño da base de datos)",
    "Updated \"%1$s\" to %2$s" : "Actualizado «%1$s» a %2$s",
    "Set log level to debug" : "Definir o nivel do rexistro na depuración",
    "Reset log level" : "Restabelecer o nivel do rexistro",
    "Starting code integrity check" : "Iniciando a comprobación da integridade do código",
    "Finished code integrity check" : "Rematada a comprobación da integridade do código",
    "%s (incompatible)" : "%s (incompatíbel)",
    "The following apps have been disabled: %s" : "As seguintes aplicacións foron desactivadas: %s",
    "Already up to date" : "Xa está actualizado",
    "Error occurred while checking server setup" : "Aconteceu un erro mentras se comprobaba a configuración do servidor",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Para obter máis detalles revise a {linkstart}documentación ↗{linkend}.",
    "unknown text" : "texto descoñecido",
    "Hello world!" : "Ola xente!",
    "sunny" : "soleado",
    "Hello {name}, the weather is {weather}" : "Ola {name}, a situación meteorolóxica é {weather}",
    "Hello {name}" : "Ola {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Estes son os resultados da súa busca<script>alert(1)</script></strong>",
    "new" : "novo",
    "_download %n file_::_download %n files_" : ["descargar %n ficheiro","descargar %n ficheiros"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "A actualización está en curso, saír desta páxina podería interromper o proceso nalgúns contornos.",
    "Update to {version}" : "Actualizar a {version}",
    "An error occurred." : "Produciuse un erro",
    "Please reload the page." : "Volva cargar a páxina.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Fallou a actualización. Obteña máis información <a href=\"{url}\">consultando o noso artigo no foro</a> para arranxar esta incidencia.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Fallou a actualización. Informe desta incidencia na <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">comunidade de Nextcloud</a>.",
    "Continue to {productName}" : "Continuar a {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["A actualización foi satisfactoria. Redirixindoo a {productName} en %n segundo.","A actualización foi satisfactoria. Redirixindoo a {productName} en %n segundos."],
    "Applications menu" : "Menú de aplicacións",
    "Apps" : "Aplicacións",
    "More apps" : "Máis aplicacións",
    "_{count} notification_::_{count} notifications_" : ["{count} notificación","{count} notificacións"],
    "No" : "Non",
    "Yes" : "Si",
    "The remote URL must include the user." : "O URL remoto debe incluír o usuario.",
    "Invalid remote URL." : "URL remoto incorrecto",
    "Failed to add the public link to your Nextcloud" : "Non foi posíbel engadir a ligazón pública ao seu Nextcloud",
    "Federated user" : "Usuario federado",
    "user@your-nextcloud.org" : "usuario@o-seu-nextcloud.org",
    "Create share" : "Crear compartición",
    "Direct link copied to clipboard" : "A ligazón directa foi copiada no portapapeis",
    "Please copy the link manually:" : "Copie a ligazón manualmente:",
    "Custom date range" : "Intervalo de datas personalizado",
    "Pick start date" : "Escolla a data de inicio",
    "Pick end date" : "Escolla a data de finalización",
    "Search in date range" : "Buscar nun intervalo de datas",
    "Search in current app" : "Buscar na aplicación actual",
    "Clear search" : "Limpar a busca",
    "Search everywhere" : "Buscar por todas partes",
    "Searching …" : "Buscando…",
    "Start typing to search" : "Comece a escribir para buscar",
    "No matching results" : "Non hai resultados coincidentes",
    "Today" : "Hoxe",
    "Last 7 days" : "Últimos 7 días",
    "Last 30 days" : "Últimos 30 días",
    "This year" : "Este ano",
    "Last year" : "Último ano",
    "Unified search" : "Busca unificada",
    "Search apps, files, tags, messages" : "Buscar aplicacións, ficheiros, etiquetas, mensaxes",
    "Places" : "Lugares",
    "Date" : "Data",
    "Search people" : "Buscar persoas",
    "People" : "Persoas",
    "Filter in current view" : "Filtrar na vista actual",
    "Results" : "Resultados",
    "Load more results" : "Cargando máis resultados",
    "Search in" : "Buscar en",
    "Log in" : "Acceder",
    "Logging in …" : "Acceder…",
    "Log in to {productName}" : "Acceda a {productName}",
    "Wrong login or password." : "Acceso ou contrasinal incorrectos.",
    "This account is disabled" : "Esta conta está desactivada",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Detectamos varias tentativas de acceso non válidas desde o seu IP. Por mor diso, o seu próximo acceso estará limitado a 30 segundos",
    "Account name or email" : "Nome da conta ou correo-e",
    "Account name" : "Nome da conta",
    "Server side authentication failed!" : "A autenticación fracasou do lado do servidor!",
    "Please contact your administrator." : "Contacte coa administración desta instancia.",
    "Temporary error" : "produciuse un erro temporal",
    "Please try again." : "Ténteo de novo",
    "An internal error occurred." : "Produciuse un erro interno",
    "Please try again or contact your administrator." : "Ténteo de novo ou póñase en contacto coa administración desta instancia.",
    "Password" : "Contrasinal",
    "Log in with a device" : "Acceder cun dispositivo",
    "Login or email" : "Acceso ou correo-e",
    "Your account is not setup for passwordless login." : "A súa conta non está configurada para o acceso sen contrasinal.",
    "Your connection is not secure" : "A conexión non é segura",
    "Passwordless authentication is only available over a secure connection." : "A autenticación sen contrasinal só está dispoñíbel nunha conexión segura.",
    "Browser not supported" : "Este navegador non é compatíbel",
    "Passwordless authentication is not supported in your browser." : "O seu navegador non admite a autenticación sen contrasinal.",
    "Reset password" : "Restabelecer o contrasinal",
    "Back to login" : "Volver ao acceso",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Se existe esta conta, enviouse unha mensaxe de restabelecemento do contrasinal ao seu enderezo de correo. Se non o recibe, verifique o seu enderezo de correo e/ou o acceso, consulte os seus cartafoles de correo lixo ou non desexado, ou pídalle axuda á súa administración local.",
    "Couldn't send reset email. Please contact your administrator." : "Non foi posíbel enviar o correo do restabelecemento. Póñase en contacto coa administración desta instancia.",
    "Password cannot be changed. Please contact your administrator." : "Non é posíbel cambiar o contrasinal. Póñase en contacto coa administración desta instancia.",
    "New password" : "Novo contrasinal",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Os seus ficheiros están cifrados. Non haberá maneira de recuperar os datos após o restabelecemento do contrasinal. Se non está seguro de que facer, póñase en contacto coa administración desta instancia antes de continuar. Confirma que quere continuar?",
    "I know what I'm doing" : "Sei o que estou a facer",
    "Resetting password" : "Restabelecendo o contrasinal",
    "Schedule work & meetings, synced with all your devices." : "Programar traballos e xuntanzas, sincronizar con todos os seus dispositivos.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Manteña aos seus compañeiros e amigos nun lugar sen filtrar a información privada.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Aplicación de correo sinxela e ben integrada con Ficheiros, Contactos e Calendario.",
    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Parolas, videochamadas, compartición de pantalla, xuntanzas en liña e conferencias web;  no seu navegador e con aplicacións móbiles.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Documentos, follas de cálculo e presentacións, feitos en Collabora Online.",
    "Distraction free note taking app." : "Aplicación para tomar notas sen distraccións.",
    "Recommended apps" : "Aplicacións recomendadas",
    "Loading apps …" : "Cargando aplicacións…",
    "Could not fetch list of apps from the App Store." : "Non foi posíbel recuperar a lista de aplicacións da tenda de aplicacións.",
    "App download or installation failed" : "Produciuse un fallo ao descargar ou instalar a aplicación",
    "Cannot install this app because it is not compatible" : "Non é posíbel instalar esta aplicación porque non ser compatíbel",
    "Cannot install this app" : "Non é posíbel instalar esta aplicación",
    "Skip" : "Omitir",
    "Installing apps …" : "Instalando aplicacións…",
    "Install recommended apps" : "Instalar aplicacións recomendadas",
    "Avatar of {displayName}" : "Avatar de {displayName}",
    "Settings menu" : "Menú de axustes",
    "Loading your contacts …" : "Cargando os seus contactos…",
    "Looking for {term} …" : "Buscando {term}…",
    "Search contacts" : "Buscar contactos",
    "Reset search" : "Restabelecer a busca",
    "Search contacts …" : "Buscar contactos…",
    "Could not load your contacts" : "Non foi posíbel cargar os seus contactos",
    "No contacts found" : "Non se atopou ningún contacto.",
    "Show all contacts" : "Amosar todos os contactos",
    "Install the Contacts app" : "Instalar a aplicación de Contactos",
    "Search" : "Buscar",
    "No results for {query}" : "Non hai resultados para {query}",
    "Press Enter to start searching" : "Prema Intro para comezar a busca",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Introduza {minSearchLength} carácter ou máis para buscar","Introduza {minSearchLength} caracteres ou máis para buscar"],
    "An error occurred while searching for {type}" : "Produciuse un erro ao buscar por {type}",
    "Search starts once you start typing and results may be reached with the arrow keys" : "A busca comeza unha vez que comeza a escribir e pódese acceder aos resultados coas teclas de frecha",
    "Search for {name} only" : "Buscar só por {name}",
    "Loading more results …" : "Cargando máis resultados…",
    "Forgot password?" : "Esqueceu o contrasinal?",
    "Back to login form" : "Volver ao formulario de acceso",
    "Back" : "Atrás",
    "Login form is disabled." : "O formulario de acceso está bloqueado.",
    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "O formulario de acceso a Nextcloud está desactivado. Use outra opción de acceso se está dispoñíbel ou póñase en contacto coa súa administración.",
    "More actions" : "Máis accións",
    "Security warning" : "Advertencia de seguranza",
    "Storage & database" : "Almacenamento e base de datos",
    "Data folder" : "Cartafol de datos",
    "Install and activate additional PHP modules to choose other database types." : "Instale e active os módulos de PHP adicionais para escoller outros tipos de bases de datos.",
    "For more details check out the documentation." : "Para obter máis detalles revise a documentación.",
    "Performance warning" : "Advertencia de rendemento",
    "You chose SQLite as database." : "Escolleu SQLite como base de datos.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite só debería empregarse para instancias mínimas e de desenvolvemento. Para produción recomendámoslle que empregue unha infraestrutura de base de datos diferente.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Se emprega clientes para a sincronización dos ficheiros, desaconséllase encarecidamente o uso de SQLite.",
    "Database user" : "Usuario da base de datos",
    "Database password" : "Contrasinal da base de datos",
    "Database name" : "Nome da base de datos",
    "Database tablespace" : "Táboa de espazos da base de datos",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Especifique o número do porto xunto co nome do anfitrión (p. ex. localhost:5432)",
    "Database host" : "Servidor da base de datos",
    "Installing …" : "Instalando…",
    "Install" : "Instalar",
    "Need help?" : "Precisa axuda?",
    "See the documentation" : "Vexa a documentación",
    "{name} version {version} and above" : "{name} versión {version} e superior",
    "This browser is not supported" : "Este navegador non é compatíbel",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "O seu navegador non é compatíbel. Actualice a unha versión máis recente ou a unha compatíbel.",
    "Continue with this unsupported browser" : "Continuar con este navegador non compatíbel",
    "Supported versions" : "Versións compatíbeis",
    "Search {types} …" : "Buscando {types}…",
    "Choose {file}" : "Escoller  {file}",
    "Choose" : "Escoller",
    "Copy to {target}" : "Copiar en {target}",
    "Copy" : "Copiar",
    "Move to {target}" : "Mover a {target}",
    "Move" : "Mover",
    "OK" : "Aceptar",
    "read-only" : "só lectura",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflito de ficheiro","{count} conflitos de ficheiros"],
    "One file conflict" : "Un conflito de ficheiro",
    "New Files" : "Novos ficheiros",
    "Already existing files" : "Ficheiros existentes",
    "Which files do you want to keep?" : "Que ficheiros quere conservar?",
    "If you select both versions, the copied file will have a number added to its name." : "Se selecciona ambas versións, o ficheiro copiado terá un número engadido ao nome.",
    "Cancel" : "Cancelar",
    "Continue" : "Continuar",
    "(all selected)" : "(todo o seleccionado)",
    "({count} selected)" : "({count} seleccionados)",
    "Error loading file exists template" : "Produciuse un erro ao cargar o modelo de ficheiro existente",
    "Saving …" : "Gardando…",
    "seconds ago" : "segundos atrás",
    "Connection to server lost" : "Falta a conexión co servidor",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Produciuse un problema a cargar a páxina, volverá cargar en %n segundo","Produciuse un problema ao cargar a páxina, volverá cargar en %n segundos"],
    "Add to a project" : "Engadir a un proxecto",
    "Show details" : "Amosar os detalles",
    "Hide details" : "Agochar os detalles",
    "Rename project" : "Cambiar o nome do proxecto",
    "Failed to rename the project" : "Produciuse un fallo ao cambiarlle o nome ao proxecto",
    "Failed to create a project" : "Produciuse un fallo ao crear o proxecto",
    "Failed to add the item to the project" : "Produciuse un fallo ao engadir un elemento o proxecto",
    "Connect items to a project to make them easier to find" : "Conecte os elementos a un proxecto para que sexan máis doados de atopar",
    "Type to search for existing projects" : "Escriba para buscar proxectos existentes",
    "New in" : "Novo en",
    "View changelog" : "Ver as notas da versión",
    "No action available" : "Non hai accións dispoñíbeis",
    "Error fetching contact actions" : "Produciuse un erro ao recuperar as accións do contacto",
    "Close \"{dialogTitle}\" dialog" : "Pechar o diálogo «{dialogTitle}».",
    "Email length is at max (255)" : "Acadouse a lonxitude máxima do correo-e (255)",
    "Non-existing tag #{tag}" : "A etiqueta #{tag} non existe",
    "Restricted" : "Restrinxida",
    "Invisible" : "Invisíbel",
    "Delete" : "Eliminar",
    "Rename" : "Cambiar o nome",
    "Collaborative tags" : "Etiquetas colaborativas",
    "No tags found" : "Non se atopou ningunha etiqueta",
    "Clipboard not available, please copy manually" : "O portapapeis non está dispoñíbel, cópieo manualmente",
    "Personal" : "Persoal",
    "Accounts" : "Contas",
    "Admin" : "Administración",
    "Help" : "Axuda",
    "Access forbidden" : "Acceso denegado",
    "Page not found" : "Non se atopou a páxina",
    "The page could not be found on the server or you may not be allowed to view it." : "Non foi posíbel atopar a páxina no servidor ou é posíbel que non teña permiso para vela.",
    "Back to %s" : "Volver a %s",
    "Too many requests" : "Demasiadas solicitudes",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Houbo demasiadas solicitudes da súa rede. Volva tentalo máis adiante ou póñase en contacto coa administración desta instancia se se trata dun erro.",
    "Error" : "Erro",
    "Internal Server Error" : "Produciuse un erro interno do servidor",
    "The server was unable to complete your request." : "O servidor non é quen de completar a súa solicitude. ",
    "If this happens again, please send the technical details below to the server administrator." : "Se volve suceder, a seguir envíe os detalles técnicos á administración do servidor.",
    "More details can be found in the server log." : "Atopará máis detalles no rexistro do servidor.",
    "For more details see the documentation ↗." : "Para obter máis detalles revise a documentación ↗.",
    "Technical details" : "Detalles técnicos",
    "Remote Address: %s" : "Enderezo remoto: %s",
    "Request ID: %s" : "ID da solicitude: %s",
    "Type: %s" : "Tipo: %s",
    "Code: %s" : "Código: %s",
    "Message: %s" : "Mensaxe: %s",
    "File: %s" : "Ficheiro: %s",
    "Line: %s" : "Liña: %s",
    "Trace" : "Traza",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Semella que está tentando reinstalar o seu Nextcloud. Non obstante o ficheiro CAN_INSTALL falta no seu directorio de configuración. Cree o ficheiro CAN_INSTALL no cartafol de configuración para continuar.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Non foi posíbel retirar CAN_INSTALL do cartafol de configuración. Retire este ficheiro manualmente.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Esta aplicación precisa JavaScript para un correcto funcionamento. {linkstart}Active  JavaScript{linkend} e volva cargar a páxina.",
    "Skip to main content" : "Ir ao contido principal",
    "Skip to navigation of app" : "Ir á navegación da aplicación",
    "Go to %s" : "Ira a %s",
    "Get your own free account" : "Obteña a súa propia conta de balde",
    "Connect to your account" : "Conectar coa súa conta",
    "Please log in before granting %1$s access to your %2$s account." : "Acceda antes de concederlle a %1$s acceso á súa conta %2$s.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Se non está a configurar un dispositivo ou aplicación nova, alguén está tentando enganalo para que lle permita o acceso aos seus datos. Neste caso non continúe e póñase en contacto coa administración do sistema.",
    "App password" : "Contrasinal da aplicación",
    "Grant access" : "Permitir o acceso",
    "Alternative log in using app password" : "Acceso alternativo usando o contrasinal da aplicación",
    "Account access" : "Acceso á conta",
    "Currently logged in as %1$s (%2$s)." : "Agora está conectado como %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Está a piques de concederlle a %1$s permiso para acceder á súa conta %2$s.",
    "Account connected" : "Conta conectada",
    "Your client should now be connected!" : "O seu cliente xa debe estar conectado!",
    "You can close this window." : "Pode pechar esta xanela.",
    "Previous" : "Anterior",
    "This share is password-protected" : "Esta compartición está protexida con contrasinal ",
    "The password is wrong or expired. Please try again or request a new one." : "O contrasinal é erróneo ou caducou. Volva tentalo ou solicite un novo.",
    "Please type in your email address to request a temporary password" : "Escriba o seu enderezo de correo para solicitar un contrasinal temporal",
    "Email address" : "Enderezo de correo",
    "Password sent!" : "Contrasinal enviado!",
    "You are not authorized to request a password for this share" : "Non ten autorización para solicitar un contrasinal para esta compartición",
    "Two-factor authentication" : "Autenticación de dous factores",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Foi activada a seguranza obrigatoria para a súa conta. Escolla un segundo factor para a autenticación. ",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Non foi posíbel cargar alomenos un dos seus métodos de autenticación de dous factores. Póñase en contacto cun administrador.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "É obrigatoria a autenticación de dous factores, mais non foi configurada na súa conta. Póñase en contacto co administrador para obter axuda.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "É obrigatoria a autenticación de dous factores, mais non foi configurada na súa conta. Continúe configurando a autenticación de dous factores.",
    "Set up two-factor authentication" : "Definir a autenticación de dous factores",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "É obrigatoria a autenticación de dous factores, mais non foi configurada na súa conta. Use un dos seus códigos de recuperación para acceder ou póñase en contacto co administrador para obter axuda.",
    "Use backup code" : "Usar código de recuperación",
    "Cancel login" : "Cancelar o acceso",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Impúxose a seguranza mellorada para a súa conta. Escolla o provedor que quere definir:",
    "Error while validating your second factor" : "Produciuse un erro ao validar o seu segundo factor",
    "Access through untrusted domain" : "Acceso a través dun dominio non fiábel",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Contacte coa administración do sistema. Se Vde. é un administrador, edite o axuste de «trusted_domains» en config/config.php coma no exemplo en config.sample.php. ",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Pode atopar máis información sobre cómo configurar isto na %1$sdocumentación%2$s.",
    "App update required" : "Precísase de actualizar a aplicación",
    "%1$s will be updated to version %2$s" : "%1$s actualizarase á versión %2$s",
    "The following apps will be updated:" : "As seguintes aplicacións foron actualizadas:",
    "These incompatible apps will be disabled:" : "Desactivaranse estas aplicacións incompatíbeis:",
    "The theme %s has been disabled." : "O tema %s foi desactivado.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Asegúrese de ter feito unha copia de seguranza da base de datos, do cartafol de configuración e do cartafol de datos, antes de proceder.",
    "Start update" : "Iniciar a actualización",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Para evitar tempos de espera nas instalacións grandes, en troques pode executar a seguinte orde desde o directorio de instalación:",
    "Detailed logs" : "Rexistros detallados",
    "Update needed" : "É necesario actualizar",
    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Vde. ten unha instancia moi grande con máis de 50 contas, faga a actualización empregando a liña de ordes.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Para obter axuda, vexa a <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentación</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Sei que se continúo facendo a actualización a través da interface web, corro o risco de que a solicitude non se execute no tempo de espera e provoque a perda de información pero teño unha copia de seguranza dos datos e sei como restaurala.",
    "Upgrade via web on my own risk" : "Anovar a través da web, correndo o risco baixo a miña responsabilidade",
    "Maintenance mode" : "Modo de mantemento",
    "This %s instance is currently in maintenance mode, which may take a while." : "Esta instancia de %s atopase en modo de mantemento, isto pode levar un anaco.",
    "This page will refresh itself when the instance is available again." : "Esta páxina actualizarase automaticamente cando a instancia estea dispoñíbel de novo.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Póñase en contacto coa administración do sistema se persiste esta mensaxe ou se aparece de forma inesperada.",
    "Currently open" : "Aberto actualmente",
    "Login with username or email" : "Acceder co nome de usuario ou co correo-e",
    "Login with username" : "Acceder co nome de usuario",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Parolas, videochamadas, compartición de pantalla, xuntanzas en liña e conferencias web;  no seu navegador e con aplicacións móbiles.",
    "You have not added any info yet" : "Aínda non engadiu ningunha información",
    "{user} has not added any info yet" : "{user} aínda non engadiu ningunha información",
    "Error opening the user status modal, try hard refreshing the page" : "Produciuse un erro ao abrir a xanela modal de estado do usuario, tente forzar a actualización da páxina",
    "Edit Profile" : "Editar o perfil",
    "The headline and about sections will show up here" : "As seccións título e sobre aparecerán aquí",
    "Error loading message template: {error}" : "Produciuse un erro ao cargar o modelo da mensaxe: {error}",
    "Very weak password" : "Contrasinal moi feble",
    "Weak password" : "Contrasinal feble",
    "So-so password" : "Contrasinal non moi aló",
    "Good password" : "Contrasinal bo",
    "Strong password" : "Contrasinal forte",
    "Profile not found" : "Non se atopou o perfil",
    "The profile does not exist." : "O perfil non existe.",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "O seu directorio de datos e os ficheiros probabelmente sexan accesíbeis desde a Internet xa que o ficheiro .htaccess non está a traballar.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Para obter información sobre como configurar o seu servidor de xeito correcto, vexa a <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentación</a>.",
    "<strong>Create an admin account</strong>" : "<strong>Crear unha conta de administración</strong>",
    "New admin account name" : "Nome da nova conta de administración",
    "New admin password" : "Novo contrasinal de administración",
    "Show password" : "Amosar o contrasinal",
    "Toggle password visibility" : "Alternar a visibilidade do contrasinal",
    "Configure the database" : "Configurar a base de datos",
    "Only %s is available." : "Só está dispoñíbel %s.",
    "Database account" : "Conta da base de datos"
},
"nplurals=2; plural=(n != 1);");
